==> haskell-sha-1.6.4.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.2
id: SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
key: SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
license: BSD3
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
exposed: True
exposed-modules:
    Data.Digest.Pure.SHA
abi: e71ccf5956ee32d7b1829e439cb70286
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/SHA-1.6.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/SHA-1.6.4.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/SHA-1.6.4.2
hs-libraries: HSSHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
depends:
    array-0.5.1.1 base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sha-1.6.4.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.2
id: SHA-1.6.4.2-6ZuKopcglGG4yoCGsd9koJ
key: SHA-1.6.4.2-6ZuKopcglGG4yoCGsd9koJ
license: BSD3
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
exposed: True
exposed-modules:
    Data.Digest.Pure.SHA
abi: 7e72861948b3b3bd63cbf95da3d6ef08
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/SHA-1.6.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/SHA-1.6.4.2
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/SHA-1.6.4.2
hs-libraries: HSSHA-1.6.4.2-6ZuKopcglGG4yoCGsd9koJ
depends:
    array-0.5.1.1 base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
